@@ -28,6 +28,7 @@ my $version = 'pnp4nagios-head';
 
 # process command line parameters
 use vars qw ( $help $debug $mode $vInfo $PNPCfg $MainCfg $last_check);
+my $start_options = $0 . " " . join(" ", @ARGV);
 Getopt::Long::Configure('bundling');
 GetOptions(
 	"h|help"     => \$help,
@@ -94,6 +95,7 @@ my $process_perfdata_cfg = 0;
 
 info("========== Starting Environment Checks ============",4);
 info("My version is: ".$version,4);
+info("Start Options: ".$start_options, 4);
 
 #
 # Read Main config file
@@ -150,6 +152,7 @@ process_perfdata_cfg($ppcfg);
 if( -r "$PNPCfg/pnp4nagios_release" ){ 
 	process_pnp4nagios_release("$PNPCfg/pnp4nagios_release");
 	info("Found PNP4Nagios version ".get_config_var('PKG_VERSION'), 0);
+	info("./configure Options ".get_config_var('CONFIGURE_ARGS'), 0) if get_config_var('CONFIGURE_ARGS');
 }else{
 	info("No pnp4nagios_release file found. This might be an older version of PNP4Nagios", 0);
 }
@@ -462,7 +465,7 @@ sub check_command_definition {
 		my $dump_file = get_config_var( $option =~m/(.*)_processing_command/ );
 		my $perfdata_spool_dir = get_config_var( 'perfdata_spool_dir');
 		#print "$dump_file\n";
-		my $regex = qr/\/bin\/mv\s$dump_file\s$perfdata_spool_dir/;
+		my $regex = qr/\/bin\/mv\s+$dump_file\s+$perfdata_spool_dir/;
 		if( $val =~ m/$regex/){
 			info ( "Command looks good",0 );
 		}else{
@@ -521,6 +524,10 @@ sub compare_config_var {
 
 sub check_perfdata_file_template {
 	$_ = shift;
+	if ( not $_ ){
+		return;
+	}
+		 
 	if( /^DATATYPE::(HOST|SERVICE)PERFDATA/ ){
 		info("PERFDATA template looks good",0);
 	}else{
