@@ -148,7 +148,7 @@ class System_Controller extends Template_Controller {
                 elseif (in_array('NONE', $users)) {
                         return 0;
                 }
-                elseif (in_array($_SERVER["REMOTE_USER"], $users)) {
+                elseif (in_array($this->auth->REMOTE_USER, $users)) {
                         return 1;
                 } else {
                         return 0;
@@ -162,7 +162,7 @@ class System_Controller extends Template_Controller {
                 elseif (in_array('NONE', $users)) {
                         return 0;
                 }
-                elseif (in_array($_SERVER["REMOTE_USER"], $users)) {
+                elseif (in_array($this->auth->REMOTE_USER, $users)) {
                         return 1;
                 } else {
                         return 0;
@@ -176,7 +176,7 @@ class System_Controller extends Template_Controller {
                 elseif (in_array('NONE', $users)) {
                         return 0;
                 }
-                elseif (in_array($_SERVER["REMOTE_USER"], $users)) {
+                elseif (in_array($this->auth->REMOTE_USER, $users)) {
                         return 1;
                 } else {
                         return 0;
@@ -190,7 +190,7 @@ class System_Controller extends Template_Controller {
                 elseif (in_array('NONE', $users)) {
                         return 0;
                 }
-                elseif (in_array($_SERVER["REMOTE_USER"], $users)) {
+                elseif (in_array($this->auth->REMOTE_USER, $users)) {
                         return 1;
                 } else {
                         return 0;
