@@ -4,7 +4,7 @@
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-<meta http-equiv="refresh" content="<?php echo $this->config->conf['refresh'] ?>"; URL="<?php echo $_SERVER['REQUEST_URI'] ?>">
+<meta http-equiv="refresh" content="<?php echo $this->config->conf['refresh'] ?>; url=<?php echo $_SERVER['REQUEST_URI'] ?>">
 <title><?php if (isset($this->title)) echo html::specialchars($this->title) ?></title>
 <?php echo html::stylesheet('media/css/common.css') ?>
 <?php echo html::stylesheet('media/css/imgareaselect-default.css') ?>
@@ -49,7 +49,21 @@ jQuery(window).load(
         window.location = link + '&start=' + start + '&end=' + end ; 
 
     }
-
+	
+	var sfilter = "<?php echo $this->session->get('sfilter') ?>";
+	var spfilter = "<?php echo $this->session->get('spfilter') ?>";
+	var pfilter = "<?php echo $this->session->get('pfilter') ?>";
+	
+	if(jQuery("#service-filter").length) {
+		console.log("send keyup")
+		jQuery("#service-filter").keyup()
+	}
+	if(jQuery("#special-filter").length) {
+		jQuery("#special-filter").keyup()
+	}
+	if(jQuery("#page-filter").length) {
+		jQuery("#page-filter").keyup()
+	}
 });
 jQuery(document).ready(function(){
     var path = "<?php echo url::base(TRUE)."/"?>";
@@ -114,9 +128,71 @@ jQuery(document).ready(function(){
         });
     });
 
+	jQuery("#service-filter").keyup(function () {
+        var sfilter = jQuery("#service-filter").val();
+		if(sfilter != "") {
+			jQuery("#service-filter").css('background-color','#ff9999');
+		}else{
+			jQuery("#service-filter").css('background-color','white');
+		}
+		jQuery.ajax({
+			type: "POST",
+			url: path + "ajax/filter/set-sfilter",
+			data: { sfilter: sfilter }
+		});
+        jQuery("#services span[id^='service']").each(function () {
+            if (jQuery(this).attr('id').search(new RegExp("service-.*" + sfilter,"i")) == 0) {
+                jQuery(this).show();
+            } else {
+                jQuery(this).hide();
+            }
+        });
+    });
 
+	jQuery("#special-filter").keyup(function () {
+        var spfilter = jQuery("#special-filter").val();
+		if(spfilter != "") {
+			jQuery("#special-filter").css('background-color','#ff9999');
+		}else{
+			jQuery("#special-filter").css('background-color','white');
+		}
+		jQuery.ajax({
+			type: "POST",
+			url: path + "ajax/filter/set-spfilter",
+			data: { spfilter: spfilter }
+		});
+        jQuery("#special-templates span[id^='special']").each(function () {
+            if (jQuery(this).attr('id').search(new RegExp("special-.*" + spfilter,"i")) == 0) {
+                jQuery(this).show();
+            } else {
+                jQuery(this).hide();
+            };
+        });
+    });
+
+	jQuery("#page-filter").keyup(function () {
+        var pfilter = jQuery("#page-filter").val();
+		if(pfilter != "") {
+			jQuery("#page-filter").css('background-color','#ff9999');
+		}else{
+			jQuery("#page-filter").css('background-color','white');
+		}
+		jQuery.ajax({
+			type: "POST",
+			url: path + "ajax/filter/set-pfilter",
+			data: { pfilter: pfilter }
+		});
+        jQuery("#pages span[id^='page']").each(function () {
+            if (jQuery(this).attr('id').search(new RegExp("page-.*" + pfilter,"i")) == 0) {
+                jQuery(this).show();
+            } else {
+                jQuery(this).hide();
+            };
+        });
+    });
 });
 
+
 <?php if (!empty($zoom_header)) {
      echo $zoom_header;
 } ?>
@@ -129,6 +205,9 @@ jQuery(document).ready(function(){
 <?php if (!empty($debug)) {
      echo $debug;
 } ?>
+<?php if (!empty($color)) {
+     echo $color;
+} ?>
 <?php if (!empty($zoom)) {
      echo $zoom;
 } ?>
